]> Pileus Git - ~andy/fetchmail/commitdiff
auth->preauth, second step.
authorEric S. Raymond <esr@thyrsus.com>
Thu, 16 Sep 1999 11:11:04 +0000 (11:11 -0000)
committerEric S. Raymond <esr@thyrsus.com>
Thu, 16 Sep 1999 11:11:04 +0000 (11:11 -0000)
svn path=/trunk/; revision=2565

NEWS
conf.c
fetchmail-FAQ.html
fetchmailconf

diff --git a/NEWS b/NEWS
index 89156f8d168f8c83d84c0b06b00402b2ad184e02..b2a9cbf04c01720c33a2c49ee09ea87d4ac76f15 100644 (file)
--- a/NEWS
+++ b/NEWS
@@ -8,7 +8,7 @@
 
                                Release Notes:
 
-fetchmail-5.0.8 (Tue Sep 14 06:56:50 EDT 1999):
+fetchmail-5.0.9 ():
 * CRAM-MD5 code now doublequotes usernames with embedded spaces.  This will
   probably fail (the RFCs don't support quoting) but it's better than nothing
   and works with at least one server.
diff --git a/conf.c b/conf.c
index 23826c8ee2bf1e72ad43ac42d4fc40b722e988df..ea7e3bad5d08d523579495bbc4f6b76c0401f50d 100644 (file)
--- a/conf.c
+++ b/conf.c
@@ -264,11 +264,11 @@ void dump_config(struct runctl *runp, struct query *querylist)
            stringdump("qvirtual", ctl->server.qvirtual);
  
            if (ctl->server.preauthenticate == A_KERBEROS_V4)
-               stringdump("auth", "kerberos_v4");
+               stringdump("preauth", "kerberos_v4");
            else if (ctl->server.preauthenticate == A_KERBEROS_V5)
-               stringdump("auth", "kerberos_v5");
+               stringdump("preauth", "kerberos_v5");
            else
-               stringdump("auth", "password");
+               stringdump("preauth", "password");
 
 #if defined(HAVE_GETHOSTBYNAME) && defined(HAVE_RES_SEARCH)
            booldump("dns", ctl->server.dns);
index 9a83608ce2b2e49a723a5ffe9efb63ab8edda170..df18f6e07674031e0c505a7f0ce1e32914b38661 100644 (file)
@@ -10,7 +10,7 @@
 <table width="100%" cellpadding=0><tr>
 <td width="30%">Back to <a href="index.html">Fetchmail Home Page</a>
 <td width="30%" align=center>To <a href="/~esr/sitemap.html">Site Map</a>
-<td width="30%" align=right>$Date: 1999/09/16 07:27:40 $
+<td width="30%" align=right>$Date: 1999/09/16 11:11:04 $
 </table>
 <HR>
 <H1>Frequently Asked Questions About Fetchmail</H1>
@@ -589,9 +589,9 @@ once you have installed the `bind' package.<P>
 <hr>
 <h2><a name="F1">F1. Why does my old .fetchmailrc file no longer work?</a></h2>
 
-<h3>If your file predates 5.0.8</h3>
+<h3>If your file predates 5.0.9</h3>
 
-In 5.0.8, the <tt>auth</tt> keyword and option were changed to
+In 5.0.9, the <tt>auth</tt> keyword and option were changed to
 <tt>preauth</tt>.<p>
 
 <h3>If your file predates 4.5.5</h3>
@@ -2472,7 +2472,7 @@ inactivity timeout.<p>
 <table width="100%" cellpadding=0><tr>
 <td width="30%">Back to <a href="index.html">Fetchmail Home Page</a>
 <td width="30%" align=center>To <a href="/~esr/sitemap.html">Site Map</a>
-<td width="30%" align=right>$Date: 1999/09/16 07:27:40 $
+<td width="30%" align=right>$Date: 1999/09/16 11:11:04 $
 </table>
 
 <P><ADDRESS>Eric S. Raymond <A HREF="mailto:esr@thyrsus.com">&lt;esr@snark.thyrsus.com&gt;</A></ADDRESS>
index 79d500eb1fb11c1ef773aa2510bccc670f1d0f4d..54e6dfad778021828ac8c3f694795d8cbe6fe97f 100755 (executable)
@@ -4,7 +4,7 @@
 # by Eric S. Raymond, <esr@snark.thyrsus.com>.
 # Requires Python with Tkinter, and the following OS-dependent services:
 #      posix, posixpath, socket
-version = "1.15"
+version = "1.16"
 
 from Tkinter import *
 from Dialog import *
@@ -74,7 +74,7 @@ class Server:
        self.protocol = 'auto'          # Default to auto protocol
        self.port = 0                   # Port number to use
        self.uidl = FALSE               # Don't use RFC1725 UIDLs by default
-       self.auth = 'password'          # Default to password authentication
+       self.preauth = 'password'       # Default to password authentication
        self.timeout = 300              # 5-minute timeout
        self.envelope = 'Received'      # Envelope-address header
        self.envskip = 0                # Number of envelope headers to skip
@@ -96,7 +96,7 @@ class Server:
            ('protocol',  'String'),
            ('port',      'Int'),
            ('uidl',      'Boolean'),
-           ('auth',      'String'),
+           ('preauth',      'String'),
            ('timeout',   'Int'),
            ('envelope',  'String'),
            ('envskip',   'Int'),
@@ -132,8 +132,8 @@ class Server:
                str = str + " envelope " + self.envelope
        if self.qvirtual:
            str = str + (" qvirtual \"%s\"\n" % (self.qvirtual,));
-       if self.auth != ServerDefaults.auth:
-           str = str + " auth " + self.auth
+       if self.preauth != ServerDefaults.preauth:
+           str = str + " preauth " + self.preauth
        if self.dns != ServerDefaults.dns or self.uidl != ServerDefaults.uidl:
            str = str + " and options"
        if self.dns != ServerDefaults.dns:
@@ -340,7 +340,7 @@ defaultports = {"auto":0,
                "IMAP-K4":143,
                "ETRN":25}
 
-authlist = ("password", "kerberos")
+preauthlist = ("password", "kerberos")
 
 listboxhelp = {
     'title' : 'List Selection Help',
@@ -1031,8 +1031,8 @@ class ServerEdit(Frame, MyWidget):
                 secwin = Frame(rightwin, relief=RAISED, bd=5)
                 Label(secwin, text="Security").pack(side=TOP)
                 # Don't actually let users set this.  KPOP sets it implicitly
#      ButtonBar(secwin, 'Authorization mode:',
#                self.auth, authlist, 1, None).pack(side=TOP)
                 if os_type == 'linux' or os_type == 'freebsd'  or 'interface' in dictmembers:
                     LabeledEntry(secwin, 'IP range to check before poll:',
                         self.interface, leftwidth).pack(side=TOP, fill=X)
@@ -1031,8 +1031,8 @@ class ServerEdit(Frame, MyWidget):
                 Label(secwin, text="Security").pack(side=TOP)
                 # Don't actually let users set this.  KPOP sets it implicitly
-                #      ButtonBar(secwin, 'Authorization mode:',
-                #                self.auth, authlist, 1, None).pack(side=TOP)
+                #      ButtonBar(secwin, 'Preauthorization mode:',
+                #                self.preauth, preauthlist, 1, None).pack(side=TOP)
                 if os_type == 'linux' or os_type == 'freebsd'  or 'interface' in dictmembers:
                     LabeledEntry(secwin, 'IP range to check before poll:',